def call(
    Boolean isArchIndependent = false,
    List ignoredArchs = [],
    Boolean isHeavyPackage = false)
{
  String distroName = 'debian'
  String distroCodename = 'trixie'
  String component = 'heuler'
  String branchName = env.CHANGE_BRANCH
  String stashFileList = '*.gz,*.bz2,*.xz,*.deb,*.ddeb,*.udeb,*.dsc,*.changes,*.buildinfo,lintian.txt'
  String archiveFileList = '*.gz,*.bz2,*.xz,*.deb,*.ddeb,*.udeb,*.dsc,*.changes,*.buildinfo'
  def packageName = projectName()
  def productionBranches = [
    'master', 'main'
  ]
  pipeline {
    agent none
    options {
      // Only 'Build source' stage requires checkout.
      skipDefaultCheckout()
    }
    stages {
      stage('Build DEB packages') {
        parallel {
          stage('Build binary - amd64') {
            agent { label (isHeavyPackage ? 'amd64-fast' : 'amd64') }
            // Always run; arch-independent packages are built here.
            steps {
              deleteDir()
              dir ('build/' + component + '/' + packageName) {
                checkout scm
              }
              sh 'PATH=$HOME/bin:$PATH BUILD_BASE="$(pwd)/build" PKGDIST_BASE="$(pwd)/pkg-dist" PLATFORM="x86" SKIP_ARCH="i386" FORCE_BUILD="yes" NO_DELAY="yes" x2go-sbuild-deb-package ' + packageName + ' ' + component + '/' + distroCodename + ' ' + branchName
              sh 'cp $(pwd)/pkg-dist/' + component + '/' + packageName + '/' + distroName + '/' + distroCodename + '/amd64/* .'
              stash(includes: stashFileList, name: 'build-amd64')
            }
            post {
              cleanup {
                deleteDir() /* clean up our workspace */
              }
            }
          }
          stage('Build binary - i386') {
            agent { label (isHeavyPackage ? 'i386-fast' : 'i386') }
            when { expression { return !isArchIndependent && !ignoredArchs.contains('i386') } }
            steps {
              deleteDir()
              dir ('build/' + component + '/' + packageName) {
                checkout scm
              }
              sh 'PATH="$HOME/bin:$PATH" && BUILD_BASE="$(pwd)/build" PKGDIST_BASE="$(pwd)/pkg-dist" PLATFORM="x86" SKIP_ARCH="amd64" SKIP_ARCH_ALL="yes" FORCE_BUILD="yes" NO_DELAY="yes" x2go-sbuild-deb-package ' + packageName + ' ' + component + '/' + distroCodename + ' ' + branchName
              sh 'cp $(pwd)/pkg-dist/' + component + '/' + packageName + '/' + distroName + '/' + distroCodename + '/i386/* .'
              stash(includes: stashFileList, name: 'build-i386')
            }
            post {
              cleanup {
                deleteDir() /* clean up our workspace */
              }
            }
          }
//          stage('Build binary - ppc64 (Big Endian)') {
//            agent { label (isHeavyPackage ? 'ppc64be-fast' : 'ppc64be') }
//            when { expression { return !isArchIndependent && !ignoredArchs.contains('ppc64be') } }
//            steps {
//              deleteDir()
//              sh 'cd $HOME/bin && BUILD_BASE="$(pwd)/build" PKGDIST_BASE="$(pwd)/pkg-dist" PLATFORM="ppc64" FORCE_BUILD="yes" NO_DELAY="yes" ./x2go-sbuild-deb-package ' + packageName + ' ' + component + '/' + distroCodename + ' ' + branchName
//              sh 'cp $HOME/pkg-dist/' + component + '/' + packageName + '/' + distroName + '/' + distroCodename + '/ppc64be/* .'
//              stash(includes: stashFileList, name: 'build-ppc64be')
//            }
//            post {
//              cleanup {
//                deleteDir() /* clean up our workspace */
//              }
//            }
//          }
//          stage('Build binary - ppc64 (Little Endian)') {
//            agent { label (isHeavyPackage ? 'ppc64le-fast' : 'ppc64le') }
//            when { expression { return !isArchIndependent && !ignoredArchs.contains('ppc64le') } }
//            steps {
//              deleteDir()
//              sh 'cd $HOME/bin && BUILD_BASE="$(pwd)/build" PKGDIST_BASE="$(pwd)/pkg-dist" PLATFORM="ppc64le" FORCE_BUILD="yes" NO_DELAY="yes" ./x2go-sbuild-deb-package ' + packageName + ' ' + component + '/' + distroCodename + ' ' + branchName
//              sh 'cp $HOME/pkg-dist/' + component + '/' + packageName + '/* .'
//              sh 'cp $HOME/pkg-dist/' + component + '/' + packageName + '/' + distroName + '/' + distroCodename + '/ppc64le/* .'
//              stash(includes: stashFileList, name: 'build-ppc64le')
//            }
//            post {
//              cleanup {
//                deleteDir() /* clean up our workspace */
//              }
//            }
//          }
//          stage('Build binary - arm64') {
//            agent { label (isHeavyPackage ? 'arm64-fast' : 'arm64') }
//            when { expression { return !isArchIndependent && !ignoredArchs.contains('arm64') } }
//            steps {
//              deleteDir()
//              sh 'cd $HOME/bin && BUILD_BASE="$(pwd)/build" PKGDIST_BASE="$(pwd)/pkg-dist" PLATFORM="arm" SKIP_ARCH="armhf" FORCE_BUILD="yes" ./x2go-sbuild-deb-package ' + packageName + ' ' + component + '/' + distroCodename + ' ' + branchName
//              sh 'cp $HOME/pkg-dist/' + component + '/' + packageName + '/' + distroName + '/' + distroCodename + '/arm64/* .'
//              stash(includes: stashFileList, name: 'build-arm64')
//            }
//            post {
//              cleanup {
//                deleteDir() /* clean up our workspace */
//              }
//            }
//          }
//          stage('Build binary - armhf') {
//            agent { label (isHeavyPackage ? 'armhf-fast' : 'armhf') }
//            when { expression { return !isArchIndependent && !ignoredArchs.contains('armhf') } }
//            steps {
//              deleteDir()
//              sh 'cd $HOME/bin && BUILD_BASE="$(pwd)/build" PKGDIST_BASE="$(pwd)/pkg-dist" PLATFORM="arm" SKIP_ARCH="arm64" FORCE_BUILD="yes" NO_DELAY="yes" ./x2go-sbuild-deb-package ' + packageName + ' ' + component + '/' + distroCodename + ' ' + branchName
//              sh 'cp $HOME/pkg-dist/' + component + '/' + packageName + '/' + distroName + '/' + distroCodename + '/armhf/* .'
//              stash(includes: stashFileList, name: 'build-armhf')
//            }
//            post {
//              cleanup {
//                deleteDir() /* clean up our workspace */
//              }
//            }
//          }
        }
      }
      stage('Results') {
        agent { label 'amd64' }
        steps {
          deleteDir()
          unstash 'build-amd64'
          // If statement can only be evaluated under a script stage.
          script {
            if (!isArchIndependent) {
//              if (!ignoredArchs.contains('ppc64be')) {
//                unstash 'build-ppc64be'
//              }
//              if (!ignoredArchs.contains('ppc64le')) {
//                unstash 'build-ppc64le'
//              }
//              if (!ignoredArchs.contains('arm64')) {
//                unstash 'build-arm64'
//              }
//              if (!ignoredArchs.contains('armhf')) {
//                unstash 'build-armhf'
//              }
              if (!ignoredArchs.contains('i386')) {
                unstash 'build-i386'
              }
            }
          }
          archiveArtifacts(artifacts: archiveFileList, fingerprint: true, onlyIfSuccessful: true)
//          sh 'cd $HOME/bin && NO_DELAY="yes" BUILD_BASE="$(pwd)/build" PKGDIST_BASE="$(pwd)/pkg-dist" ./x2go-upload-deb-package ' + packageName + ' ' + component + '/' + distroCodename
        }
        post {
          cleanup {
            deleteDir() /* clean up our workspace */
          }
        }
      }
    }
//    post {
//      always {
//        node('master') {
//          script {
//            if (branchName in productionBranches) {
//              notifyBuildStatus(
//                currentBuild,
//                /* jobDescription */ "DEB build of ${JOB_NAME}",
//                /* jobUrl */ env.JOB_URL
//              );
//            }
//          }
//        }
//      }
//    }
  }
}

def projectName() {
  jobNameSplit = env.JOB_NAME.split("%2F|/")
  return jobNameSplit[jobNameSplit.size()-2]
}
